package com.br.fechadura.mobile.ui.screens

import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material.icons.filled.Create
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import com.br.fechadura.mobile.R
import com.br.fechadura.mobile.ui.theme.FechaduraColor
import com.br.fechadura.mobile.ui.theme.FechaduraMobileTheme

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun PerfilScreen(navController: NavController) {
    val showAlert = remember { mutableStateOf(false) }
    Scaffold(
        topBar = {
            TopAppBar(
                title = { Text("Tela de Perfil") },
                colors = TopAppBarDefaults.topAppBarColors(
                    containerColor = FechaduraColor
                ),
                navigationIcon = {
                    IconButton(onClick = { navController.navigate("inicio") }) {
                        Icon(
                            imageVector = Icons.AutoMirrored.Filled.ArrowBack,
                            contentDescription = "Voltar para início"
                        )
                    }
                }
            )
        }
    ) { innerPadding ->
            Column(
                modifier = Modifier
                    .padding(innerPadding)
                    .padding(top = 15.dp)
                    .verticalScroll(rememberScrollState())
                    .fillMaxSize(),
                verticalArrangement = Arrangement.spacedBy(15.dp),
                horizontalAlignment = Alignment.CenterHorizontally
            ) {
                Text(
                    text = "Minha conta",
                    style = MaterialTheme.typography.headlineMedium,
                    color = Color.Black
                )
                Box(
                    modifier = Modifier.padding(16.dp)
                ) {
                    Image(
                        modifier = Modifier.clip(shape = CircleShape),
                        contentDescription = "Foto de perfil",
                        painter = painterResource(id = R.drawable.macaco)
                    )
                    Button(
                        onClick = {

                        },
                        shape = CircleShape,
                        contentPadding = PaddingValues(0.dp),
                        modifier = Modifier
                            .size(50.dp)
                            .align(Alignment.BottomEnd)
                    ) {
                        Icon(Icons.Default.Create, contentDescription = "ícone de lupa")
                    }

                }
                Text(
                    style = MaterialTheme.typography.headlineSmall,
                    text = "Vinicius Daniel Monteiro",
                    color = Color.Black
                )
                Text(
                    text = "vinicius.m@estudante.ifro.edu.br",
                    style = TextStyle(
                        fontSize = MaterialTheme.typography.bodySmall.fontSize,
                        color = Color.Gray
                    )
                )
                Button(
                    onClick = {
                        showAlert.value = true
                    },
                    modifier = Modifier.padding(top = 24.dp)
                ) { Text(text = "Sair") }
            }

            if (showAlert.value) {
                AlertDialog(onDismissRequest = {
                    showAlert.value = false
                },
                    title = {
                        Text(text = "Tem certeza que deseja sair?")
                    },
                    text = {
                        Text("Não será possível acessar informações e receber notificações pessoais.")
                    },
                    confirmButton = {
                        Button(
                            onClick = {
                                showAlert.value = false
                                navController.navigate("inicio")
                            }
                        ) {
                            Text(text = "Sair")
                        }
                    },
                    dismissButton = {
                        Button(
                            onClick = {
                                showAlert.value = false
                            }
                        ) {
                            Text("Cancelar")
                        }
                    }
                )
            }
    }
}

@Preview
@Composable
private fun preview() {
    PerfilScreen(navController = rememberNavController())
}