
import android.widget.Toast
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.layout.wrapContentSize
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.LazyRow
import androidx.compose.foundation.lazy.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowDropDown
import androidx.compose.material.icons.filled.Check
import androidx.compose.material.icons.filled.Close
import androidx.compose.material.icons.filled.Edit
import androidx.compose.material.icons.filled.MoreVert
import androidx.compose.material.icons.filled.Person
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Checkbox
import androidx.compose.material3.Divider
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ExposedDropdownMenuBox
import androidx.compose.material3.ExposedDropdownMenuDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.MaterialTheme.colorScheme
import androidx.compose.material3.ModalBottomSheet
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Surface
import androidx.compose.material3.Switch
import androidx.compose.material3.SwitchDefaults
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.rememberModalBottomSheetState
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import androidx.wear.compose.material.Chip
import com.br.fechadura.mobile.sampledata.sampleDataDoors
import com.br.fechadura.mobile.sampledata.sampleDataGroupDoors
import com.br.fechadura.mobile.ui.theme.CorDeTudo

import kotlinx.coroutines.launch

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun CadastrarGrupoUsuario(navController: NavController) {
    var nome by remember { mutableStateOf("") }
    var descricao by remember { mutableStateOf("") }
    var ativo by remember { mutableStateOf(true) }
    val scope = rememberCoroutineScope()
    val sheetState = rememberModalBottomSheetState()
    var selectedPortas by remember { mutableStateOf(setOf<String>()) }
    var showBottomSheet by remember { mutableStateOf(false) }
    var selectedText by remember { mutableStateOf("Selecione os grupos de portas") }
    var searchQuery by remember { mutableStateOf("") }

    Scaffold { innerPadding ->
        Column(
            modifier = Modifier
                .padding(innerPadding)
                .padding(16.dp)
                .fillMaxSize(),
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.Top
        ) {
            Text(
                text = "Cadastrar Grupo de Usuário",
                style = MaterialTheme.typography.titleLarge,
                modifier = Modifier.padding(bottom = 24.dp)
            )

            OutlinedTextField(
                value = nome,
                onValueChange = { nome = it },
                label = { Text(text = "Nome") },
                placeholder = { Text(text = "Digite o nome") },
                leadingIcon = { Icon(imageVector = Icons.Default.Person, contentDescription = null) },
                modifier = Modifier.fillMaxWidth()
            )

            Spacer(modifier = Modifier.height(16.dp))

            OutlinedTextField(
                value = descricao,
                onValueChange = { descricao = it },
                label = { Text(text = "Descrição") },
                placeholder = { Text(text = "Digite a descrição do grupo") },
                leadingIcon = { Icon(imageVector = Icons.Default.Edit, contentDescription = null) },
                modifier = Modifier.fillMaxWidth()
            )

            Spacer(modifier = Modifier.height(16.dp))

            Row(
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(vertical = 16.dp),
                verticalAlignment = Alignment.CenterVertically
            ) {
                Text(
                    text = "Ativo:",
                    modifier = Modifier.weight(1f)
                )
                Switch(
                    checked = ativo,
                    onCheckedChange = { ativo = it },
                    colors = SwitchDefaults.colors(
                        checkedTrackColor = Color(0xFF4CAF50),
                        uncheckedThumbColor = Color(0xFFB2B2B2),
                        uncheckedTrackColor = Color(0xFFDDDDDD),
                    ),
                    thumbContent = if (ativo) {
                        {
                            Icon(
                                imageVector = Icons.Filled.Check,
                                contentDescription = null,
                                modifier = Modifier.size(SwitchDefaults.IconSize),
                            )
                        }
                    } else {
                        null
                    }
                )
            }

            Spacer(modifier = Modifier.height(16.dp))

            Box(
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(bottom = 16.dp)
            ) {
                OutlinedTextField(
                    value = selectedText,
                    onValueChange = {},
                    readOnly = true,
                    trailingIcon = {
                        Icon(
                            imageVector = Icons.Default.ArrowDropDown,
                            contentDescription = "Open Bottom Sheet",
                            modifier = Modifier.clickable { showBottomSheet = true }
                        )
                    },
                    modifier = Modifier
                        .fillMaxWidth()
                        .clickable { showBottomSheet = true }
                )
            }

            if (showBottomSheet) {
                ModalBottomSheet(
                    onDismissRequest = { showBottomSheet = false },
                    sheetState = sheetState
                ) {
                    Column(
                        modifier = Modifier
                            .fillMaxSize()
                            .padding(16.dp)
                    ) {
                        Text(
                            text = "Portas",
                            fontSize = 16.sp,
                            style = MaterialTheme.typography.titleLarge,
                            modifier = Modifier
                                .fillMaxWidth()
                                .wrapContentSize(Alignment.Center),
                        )

                        // Barra de pesquisa
                        OutlinedTextField(
                            value = searchQuery,
                            onValueChange = { searchQuery = it },
                            label = { Text(text = "Pesquisar portas") },
                            modifier = Modifier.fillMaxWidth()
                        )

                        Spacer(modifier = Modifier.height(16.dp))

                        // Chips para portas selecionadas
                        if (selectedPortas.isNotEmpty()) {
                            LazyRow(
                                modifier = Modifier
                                    .fillMaxWidth()
                                    .padding(vertical = 8.dp),
                                horizontalArrangement = Arrangement.spacedBy(8.dp),
                                contentPadding = PaddingValues(horizontal = 8.dp)
                            ) {
                                items(selectedPortas.toList()) { porta ->
                                    Surface(
                                        modifier = Modifier.padding(4.dp),
                                        color = Color(0xFF4CAF50).copy(alpha = 0.1f), // Cor de fundo do chip
                                        shape = MaterialTheme.shapes.small,
                                        onClick = {
                                            // Remove a porta da seleção ao clicar no chip
                                            val updatedSelection = selectedPortas - porta
                                            selectedPortas = updatedSelection
                                            selectedText = if (selectedPortas.isEmpty()) {
                                                "Selecione os grupos de portas"
                                            } else {
                                                selectedPortas.joinToString(", ")
                                            }
                                        }
                                    ) {
                                        Row(
                                            verticalAlignment = Alignment.CenterVertically,
                                            modifier = Modifier.padding(8.dp)
                                        ) {
                                            Text(
                                                text = porta,
                                                color = Color(0xFF4CAF50), // Cor do texto do chip
                                                style = MaterialTheme.typography.bodyMedium
                                            )
                                            Spacer(modifier = Modifier.width(4.dp))
                                            IconButton(onClick = {
                                                // Remove a porta da seleção
                                                val updatedSelection = selectedPortas - porta
                                                selectedPortas = updatedSelection
                                                selectedText = if (selectedPortas.isEmpty()) {
                                                    "Selecione os grupos de portas"
                                                } else {
                                                    selectedPortas.joinToString(", ")
                                                }
                                            }) {
                                                Icon(
                                                    imageVector = Icons.Default.Close,
                                                    contentDescription = "Remover porta",
                                                    tint = Color(0xFF4CAF50) // Cor do ícone de remoção
                                                )
                                            }
                                        }
                                    }
                                }
                            }
                        }

                        Spacer(modifier = Modifier.height(8.dp))

                        // Lista de portas com rolagem
                        val filteredPortas = sampleDataGroupDoors
                            .filter { it.nome.contains(searchQuery, ignoreCase = true) }
                            .filterNot { it.nome in selectedPortas } // Remove portas selecionadas da lista

                        LazyColumn(
                            verticalArrangement = Arrangement.spacedBy(8.dp),
                            modifier = Modifier.fillMaxSize()
                        ) {
                            items(filteredPortas) { portas ->
                                Column(
                                    modifier = Modifier
                                        .fillMaxWidth()
                                        .clickable {
                                            val updatedSelection = if (selectedPortas.contains(portas.nome)) {
                                                selectedPortas - portas.nome
                                            } else {
                                                selectedPortas + portas.nome
                                            }
                                            selectedPortas = updatedSelection
                                            selectedText = if (selectedPortas.isEmpty()) {
                                                "Selecione os grupos de portas"
                                            } else {
                                                selectedPortas.joinToString(", ")
                                            }
                                        }
                                        .padding(vertical = 8.dp)
                                        .background(
                                            if (selectedPortas.contains(portas.nome))
                                                Color(0x1F4CAF50) // Cor de fundo quando selecionado
                                            else Color.Transparent
                                        )
                                ) {
                                    Text(
                                        text = portas.nome,
                                        modifier = Modifier
                                            .fillMaxWidth()
                                            .padding(16.dp),
                                        style = MaterialTheme.typography.bodyLarge
                                    )
                                    Divider()
                                }
                            }
                        }

                        Spacer(modifier = Modifier.height(16.dp))

                        Button(onClick = {
                            scope.launch { sheetState.hide() }.invokeOnCompletion {
                                if (!sheetState.isVisible) {
                                    showBottomSheet = false
                                }
                            }
                        }) {
                            Text("Fechar")
                        }
                    }
                }
            }
        }
    }
}





@Preview(showSystemUi = true)
@Composable
private fun CadastrarGrupoUsuarioPreview() {
    CadastrarGrupoUsuario(navController = rememberNavController())

}
