package com.br.fechadura.mobile.ui.screens.grupoUsuarios

import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.navigation.NavController
import com.br.fechadura.mobile.sampledata.sampleDataGroupDoors
import com.br.fechadura.mobile.sampledata.sampleDataGroupUser
import com.br.fechadura.mobile.ui.components.TopAppBar
import com.br.fechadura.mobile.ui.components.BottomAppBar
import com.br.fechadura.mobile.ui.components.grupoPorta.TabelaGrupoPorta
import com.br.fechadura.mobile.ui.components.grupoUsuario.TabelaGrupoUsuario
import com.br.fechadura.mobile.ui.theme.FechaduraColor

@Composable
fun GrupoUsuarioScreen(
    navController: NavController,
    searchText: String = ""
) {
    var text by remember { mutableStateOf(searchText) }
    val searchedGroupUsers = remember(text) {
        if (text.isNotBlank()) {
            sampleDataGroupUser.filter { groupDoor ->
                groupDoor.nome.contains(text , ignoreCase = true)
            }
        } else sampleDataGroupUser
    }
    Scaffold(
        topBar = {
            TopAppBar(
                navController = navController,
                title = "Grupo de Usuários",
                searchText = text,
                onSearchChange = { text = it },
                showBackButton = true
            )
        },
        bottomBar = {
            BottomAppBar(navController = navController)
        },
        floatingActionButton = {
            FloatingActionButton(onClick = { navController.navigate("cadastrar-grupo-usuario") }, containerColor = FechaduraColor) {
                Icon(Icons.Default.Add, contentDescription = "Add")
            }
        }
    ) { innerPadding ->
        Column(
            modifier = Modifier
                .fillMaxSize()
                .padding(innerPadding) ,
            verticalArrangement = Arrangement.Center ,
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            if (searchedGroupUsers.isEmpty()) {
                Text(
                    text = "Nenhum grupo encontrado",
                    modifier = Modifier.fillMaxSize(),
                    textAlign = TextAlign.Center
                )
            } else {
                LazyColumn(
                    modifier = Modifier
                        .fillMaxWidth()
                        .fillMaxHeight(),
                    verticalArrangement = Arrangement.Top
                ) {
                    items(searchedGroupUsers) { gu ->
                        TabelaGrupoUsuario(grupoUsuario = gu)
                    }
                }
            }
        }
    }
}
