package com.br.fechadura.mobile.ui.screens.portas

import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.style.TextAlign
import androidx.navigation.NavController
import com.br.fechadura.mobile.sampledata.sampleDataDoors
import com.br.fechadura.mobile.ui.components.TopAppBar
import com.br.fechadura.mobile.ui.components.BottomAppBar
import com.br.fechadura.mobile.ui.components.Porta.TabelaPorta
import com.br.fechadura.mobile.ui.theme.FechaduraColor

@Composable
fun PortaScreen(
    navController: NavController,
    searchText: String = ""
) {
    var text by remember { mutableStateOf(searchText) }
    val searchedDoors = remember(text) {
        if (text.isNotBlank()) {
            sampleDataDoors.filter { porta ->
                porta.descricao.contains(text, ignoreCase = true) ||
                        porta.ambiente.contains(text, ignoreCase = true) ?: false
            }
        } else sampleDataDoors
    }
    Scaffold(
        topBar = {
            TopAppBar(
                navController = navController,
                title = "Portas",
                searchText = text,
                onSearchChange = { text = it },
                showBackButton = true
            )
        },
        bottomBar = {
            BottomAppBar(navController = navController)
        },
        floatingActionButton = {
            FloatingActionButton(onClick = {navController.navigate("cadastrar-porta") }, containerColor = FechaduraColor) {
                Icon(Icons.Default.Add, contentDescription = "Add")
            }
        }
    ) { innerPadding ->
        Column(
            modifier = Modifier
                .fillMaxSize()
                .padding(innerPadding) ,

        ) {
            if (searchedDoors.isEmpty()) {
                // Caso nenhum usuário seja encontrado, pode-se exibir uma mensagem ou algo similar
                Text(
                    text = "Nenhuma porta encontrada",
                    modifier = Modifier.fillMaxSize(),
                    textAlign = TextAlign.Center
                )
            } else {
                LazyColumn(
                    modifier = Modifier
                        .fillMaxWidth()
                        .fillMaxHeight(),
                    verticalArrangement = Arrangement.Top
                ) {
                    items(searchedDoors) { p ->
                        TabelaPorta(porta = p, navController)
                    }
                }
            }
        }
    }
}
