package com.br.fechadura.mobile.ui.screens.usuario

import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import com.br.fechadura.mobile.sampledata.sampleData
import com.br.fechadura.mobile.ui.components.usuario.TabelaUsuario
import com.br.fechadura.mobile.ui.components.TopAppBar
import com.br.fechadura.mobile.ui.components.BottomAppBar
import com.br.fechadura.mobile.ui.theme.FechaduraColor

@Composable
fun UsuarioScreen(
    navController: NavController,
    searchText: String = ""
) {
    var text by remember { mutableStateOf(searchText) }
    var presses by remember { mutableIntStateOf(0) }
    val searchedUsers = remember(text) {
        if (text.isNotBlank()) {
            sampleData.filter { usuario ->
                usuario.nome.contains(text, ignoreCase = true) ||
                        usuario.email?.contains(text, ignoreCase = true) ?: false
            }
        } else sampleData
    }

    Scaffold(
        topBar = {
            TopAppBar(
                navController = navController,
                title = "Usuários",
                searchText = text,
                onSearchChange = { text = it },
                showBackButton = true
            )
        },
        bottomBar = {
            BottomAppBar(navController = navController)
        },
        floatingActionButton = {
            FloatingActionButton(onClick = { navController.navigate("cadastrar-usuario") }, containerColor = FechaduraColor) {
                Icon(Icons.Default.Add, contentDescription = "Add")
            }
        }

    ) { innerPadding ->
        Column(
            modifier = Modifier
                .fillMaxSize()
                .padding(innerPadding)
        ) {
            if (searchedUsers.isEmpty()) {
                Text(
                    text = "Nenhum usuário encontrado",
                    modifier = Modifier.fillMaxSize(),
                    textAlign = TextAlign.Center
                )
            } else {
                LazyColumn(
                    modifier = Modifier
                        .fillMaxWidth()
                        .fillMaxHeight(),
                    verticalArrangement = Arrangement.Top
                ) {
                    items(searchedUsers) { u ->
                        TabelaUsuario(usuario = u, navController)
                    }
                }
            }
        }
    }
}



@Preview
@Composable
private fun UsuarioPreview() {
    UsuarioScreen(navController = rememberNavController())
}
